@@ -1,7 +1,8 @@
 from .bandit import optimalOAB, simulateOAB
 from .dodge.dodge_chain import ChainPlanBinomial, ChainPlanPoisson
 from .dodge.dodge_curtailed import curtailedBinomial
-from .dodge.dodge_double import DSPlanBinomial, DSPlanPoisson
+from .dodge.dodge_double import (DSPlanBinomial, DSPlanHypergeom, DSPlanNormal,
+                                 DSPlanPoisson)
 from .dodge.dodge_other import (lotSensitiveComplianceSampPlan,
                                 variableSampPlanKnown, variableSampPlanUnknown)
 from .dodge.dodge_sequential import sequentialDesign
