@@ -67,7 +67,7 @@ class EWMA:
 
         if center is None:
             center = statistics.center
-        std_dev = qccStatistic.sd(data, std_dev, sizes=sizes)
+        std_dev = qccStatistic.sd(data, std_dev=std_dev, sizes=sizes)
 
         self.data = data
         self.statistics = statistics.statistics
@@ -105,7 +105,8 @@ class EWMA:
         ax.plot(self.x, self.y, color='black')
         if v.size > 0:
             ax.plot(self.x[v], self.y[v], linestyle='None', marker='s', color='red')
-            ax.plot(np.delete(self.x, v), np.delete(self.y, v), linestyle='None', marker='o', color='black', markersize=4)
+            ax.plot(np.delete(self.x, v), np.delete(self.y, v), linestyle='None',
+                    marker='o', color='black', markersize=4)
         ax.axhline(self.center, color='grey')
         ax.plot(self.x, self.ucl, color='black', linestyle='--')
         ax.plot(self.x, self.lcl, color='black', linestyle='--')
